@@ -2,14 +2,19 @@
 
 """Lookup and instantiate classes with style."""
 
-from .api import Hint, HintOrType, HintType, Resolver, get_cls, get_subclasses, normalize_string
+from .api import Hint, HintOrType, HintType, KeywordArgumentError, Resolver, get_cls, get_subclasses, normalize_string
 
 __all__ = [
+    # Type Hints
     'Hint',
     'HintType',
     'HintOrType',
+    # Classes
     'Resolver',
+    # Utilities
     'get_cls',
     'get_subclasses',
     'normalize_string',
+    # Exceptions
+    'KeywordArgumentError',
 ]
