@@ -3,6 +3,7 @@
 """Resolve classes."""
 
 import inspect
+import logging
 from operator import attrgetter
 from textwrap import dedent
 from typing import (
@@ -10,10 +11,13 @@ from typing import (
     TypeVar, Union,
 )
 
+from pkg_resources import iter_entry_points
+
 if TYPE_CHECKING:
     import click
 
 __all__ = [
+    # Type Hints
     'InstOrType',
     'Lookup',
     'LookupType',
@@ -21,10 +25,14 @@ __all__ = [
     'Hint',
     'HintType',
     'HintOrType',
+    # Classes
     'Resolver',
+    # Utilities
     'get_subclasses',
     'get_cls',
     'normalize_string',
+    # Exceptions
+    'KeywordArgumentError',
 ]
 
 X = TypeVar('X')
@@ -40,6 +48,24 @@ Hint = Optional[Lookup[X]]
 HintType = Hint[Type[X]]
 HintOrType = Hint[InstOrType[X]]
 
+logger = logging.getLogger(__name__)
+
+
+class KeywordArgumentError(TypeError):
+    """Thrown when missing a keyword-only argument."""
+
+    def __init__(self, cls, s: str):
+        """Initialize the error.
+
+        :param cls: The class that was trying to be instantiated
+        :param s: The string describing the original type error
+        """
+        self.cls = cls
+        self.name = s.rstrip("'").rsplit("'", 1)[1]
+
+    def __str__(self) -> str:  # noqa:D105
+        return f"{self.cls.__name__}: __init__() missing 1 required keyword-only argument: '{self.name}'"
+
 
 class Resolver(Generic[X]):
     """Resolve from a list of classes."""
@@ -133,6 +159,19 @@ class Resolver(Generic[X]):
             **kwargs,
         )
 
+    @classmethod
+    def from_entrypoint(cls, group: str, *, base: Type[X], **kwargs) -> 'Resolver':
+        """Make a resolver from the classes registered at the given entrypoint."""
+        classes = set()
+        for entry in iter_entry_points(group=group):
+            try:
+                subcls = entry.load()
+            except ImportError:
+                logger.warning('could not load %s', entry.name)
+            else:
+                classes.add(subcls)
+        return Resolver(classes=classes, base=base, **kwargs)
+
     def normalize_inst(self, x: X) -> str:
         """Normalize the class name of the instance."""
         return self.normalize_cls(x.__class__)
@@ -145,14 +184,14 @@ class Resolver(Generic[X]):
         """Normalize the string with this resolve's suffix."""
         return normalize_string(s, suffix=self.suffix)
 
-    def lookup(self, query: Hint[Type[X]]) -> Type[X]:
+    def lookup(self, query: Hint[Type[X]], default: Optional[Type[X]] = None) -> Type[X]:
         """Lookup a class."""
         return get_cls(
             query,
             base=self.base,
             lookup_dict=self.lookup_dict,
             lookup_dict_synonyms=self.synonyms,
-            default=self.default,
+            default=default or self.default,
             suffix=self.suffix,
         )
 
@@ -169,7 +208,12 @@ class Resolver(Generic[X]):
         """Instantiate a class with optional kwargs."""
         if query is None or isinstance(query, (str, type)):
             cls: Type[X] = self.lookup(query)
-            return cls(**(pos_kwargs or {}), **kwargs)  # type: ignore
+            try:
+                return cls(**(pos_kwargs or {}), **kwargs)  # type: ignore
+            except TypeError as e:
+                if 'required keyword-only argument' in e.args[0]:
+                    raise KeywordArgumentError(cls, e.args[0])
+                raise e
 
         # An instance was passed, and it will go through without modification.
         return query
